@@ -294,7 +294,6 @@ blavaan <- function(...,  # default lavaan arguments
     # ordinal only for stan
     ordmod <- lavInspect(LAV, 'categorical')
     if(ordmod) {
-        stop("blavaan ERROR: ordinal models are not (yet) available.")
         if(target != "stan") stop("blavaan ERROR: ordinal variables only work for target='stan'.")
     }
         
@@ -908,7 +907,7 @@ blavaan <- function(...,  # default lavaan arguments
         lavInspect(blavaan, "post.check")
     }
 
-    if(jag.do.fit & lavoptions$warn){
+    if(jag.do.fit & lavoptions$warn & !prisamp){
         if(any(blavInspect(blavaan, 'neff') < 100)){
             warning("blavaan WARNING: Small effective sample sizes (< 100) for some parameters.", call. = FALSE)
         }
